/**
 *******************************************************************************
 * @file  system_RIN32M3.c
 * @brief sample program for R-IN32M3
 * 
 * @note 
 * Copyright (C) 2011-2013 Renesas Electronics Corporation 
 * Copyright (C) 2011-2013 Renesas Micro Systems Co., Ltd. 
 * 
 * @par
 *  This is a sample program. 
 *  Renesas Electronics assumes no responsibility for any losses incurred. 
 * 
 *                                                              modified by Keil
 *******************************************************************************
 */

/*============================================================================*/
/* I N C L U D E                                                              */
/*============================================================================*/
#include "RIN32M3.h"
#include "system_RIN32M3.h"

/*============================================================================*/
/* D E F I N E                                                                */
/*============================================================================*/
/* CC-Link IE WDT */
#define CCIWDT							(*((volatile uint16_t *) (0x40100962)))

/*============================================================================*/
/* V A R I A B L E                                                            */
/*============================================================================*/
uint32_t SystemCoreClock = RIN32M3_SYSCLK ;

// Keil
// functions from C startup which are not covered by the assembler startup
//
extern uint32_t __Vectors;
extern void $Super$$main(void);

/**
 ******************************************************************************
  @brief  Sub main
  @param  none
  @retval none
 ******************************************************************************
*/
void $Sub$$main(void)
{
	//--------------------------
	// Replace vectors address 
    // (Scatter Loader copied the Vectors before in case a scatter file is used.)
	//--------------------------
	SCB->VTOR = (uint32_t)&__Vectors;

	//--------------------------
	// Main program
	//--------------------------
	$Super$$main();
}

/**
 ******************************************************************************
  @brief  Main program (dummy)
  @param  none
  @retval 0
 ******************************************************************************
*/
#ifndef OSLESS
#include "kernel.h"
extern ER hwos_setup(void);

int main(void)
{
	//--------------------------
	// Setup HWRTOS
	//--------------------------
	hwos_setup();

	return 0;
}
#endif	// OSLESS


/*============================================================================*/
/* P R O G R A M                                                              */
/*============================================================================*/
/**
 ******************************************************************************
  @brief  System initialize
  @param  none
  @retval none
 ******************************************************************************
*/
void SystemInit(void)
{

	// --- Setup Cortex-M3 core ---
	SCB->SHCSR = 0x00070000;						// Bus,Usage,Mem Fault Handler Enable

#ifdef RIN32M3_CL
	CCIWDT = 0x0000;								// Disable watch dog timer in CC-Link IE module
#endif

	// --- Setup memory controller ---
	// ToDo: Please modify wait setting according to user board. Default setting is slowest.
	RIN_MEMC->SMC0 = 0x0000ffff;					// Access wait setting for CS0
//	RIN_MEMC->PRC  = 0x20010001;					// Page ROM control for CS0
	RIN_MEMC->SMC1 = 0x0000ffff;					// Access wait setting for CS1
	RIN_MEMC->SMC2 = 0x0000ffff;					// Access wait setting for CS2
	RIN_MEMC->SMC3 = 0x0000ffff;					// Access wait setting for CS3
}

/**
 ******************************************************************************
  @brief  System core clock update
  @param  none
  @retval none
 ******************************************************************************
*/
void SystemCoreClockUpdate(void)
{

}
