/**
 *******************************************************************************
 * @file  main.c
 * @brief OS-less sample program for R-IN32M3
 * 
 * @note 
 * Copyright (C) 2012,2013 Renesas Electronics Corporation 
 * Copyright (C) 2012,2013 Renesas Micro Systems Co., Ltd. 
 * 
 * @par
 *  This is a sample program. 
 *  Renesas Electronics assumes no responsibility for any losses incurred. 
 * 
 *******************************************************************************
 */

/*============================================================================*/
/* I N C L U D E                                                              */
/*============================================================================*/
#include <stdio.h>
#include <time.h>

#include "uart/uart.h"
#include "timer/timer.h"

/*============================================================================*/
/* D E F I N E                                                                */
/*============================================================================*/
#ifdef __CC_ARM
#define COMPILER_VERSION "ARM "__VERSION__
#elif __GNUC__
#define COMPILER_VERSION "GCC "__VERSION__
#elif __ICCARM__
#define COMPILER_VERSION __VERSION__
#else
#define COMPILER_VERSION "Please put compiler version here (e.g. gcc 4.1)"
#endif

#define BOOT_MODE(b) \
	((b==0)?"Parallel Flash":(b==1)?"Serial Flash":(b==2)?"External Micon":"Instruction RAM")

#define LED_INIT()													\
{																	\
	RIN_RTPORT->RP3B  = 0x00;			/* RPORT 3(LED) */			\
	RIN_RTPORT->RPM3B = 0x00;			/* RPort 3(LED) output */	\
}
#define LED_INVERT(d)												\
{																	\
	RIN_RTPORT->RP3B ^= (d);										\
}

/*============================================================================*/
/* V A R I A B L E                                                            */
/*============================================================================*/

/*============================================================================*/
/* E X T E R N                                                                */
/*============================================================================*/

/*============================================================================*/
/* S T A T I C   F U N C T I O N   P R O T O T Y P E                          */
/*============================================================================*/

/*============================================================================*/
/* P R O G R A M                                                              */
/*============================================================================*/
/**
 *******************************************************************************
  @brief  Main
  @param  --
  @return always 0
 *******************************************************************************
*/
int main(void)
{
	uint8_t c;
	clock_t prev_time;
	clock_t curr_time;
	uint32_t boot_mode;

	/* Initialize LED */
	LED_INIT();
	
	/* Initialize driver */
	uart_init(SYS_UART_CH);				/* UART */
	clock_init();						/* Timer */
	
	/* Opening message */
	boot_mode = ((RIN_SYS->MDMNT >> 7) & 0x3);
	printf("\n");
	printf("hello world\n");
	printf("- compiler  =%s\n", COMPILER_VERSION);
	printf("- boot mode =%s\n", BOOT_MODE(boot_mode));
	
	/* main loop */
	prev_time = clock();
	curr_time = prev_time;
	while (1)
	{
		/* check input key */
		c = (uint8_t)getchar();
		if (c == ' ')
		{
			break;
		}
		else if ((c >= '0') && (c <= '7'))
		{
			LED_INVERT((1 << (c - '0')));
		}
		else if (c == 'c')
		{
			curr_time = clock();
		}

		/* check interval */
		if (prev_time != curr_time)
		{
			printf(" (interval =%lu ms)\n", ((curr_time - prev_time) / (CLOCKS_PER_SEC / 1000)));
			prev_time = curr_time;
		}
	}
	
	/* Ending message */
	printf("\n");
	printf("bye\n");

	return 0;
}


