;/*****************************************************************************
; * @file:    startup_RIN32M3.s
; * @purpose: CMSIS Cortex-M3 Core Device Startup File
; *           for the Renesas R-IN32M3 Device Series
; * @version: V1.00
; * @date:    03. April 2014
; *------- <<< Use Configuration Wizard in Context Menu >>> ------------------
; *
; * Copyright (C) 2011-2014 ARM Limited. All rights reserved.
; * ARM Limited (ARM) is supplying this software for use with Cortex-M3
; * processor based microcontrollers.  This file can be freely distributed
; * within development tools that are supporting such ARM based processors.
; *
; * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
; * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
; * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
; * ARM SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR
; * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
; *
; *****************************************************************************/


; <h> Stack Configuration
;   <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Stack_Size      EQU     0x00001000

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp


; <h> Heap Configuration
;   <o>  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Heap_Size       EQU     0x00001000

                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit


                PRESERVE8
                THUMB

; Vector Table Mapped to ROM
                AREA    DATA_ROM, DATA, READONLY
__Vectors_ROM   DCD     __initial_sp              ;        0: Top of Stack
                DCD     Reset_Handler             ;        1: Reset Handler
                DCD     NMI_Handler_ROM           ;        2: NMI Handler
                DCD     HardFault_Handler_ROM     ;        3: Hard Fault Handler
				
				
; Vector Table Mapped to Address 0 at Reset
                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors

__Vectors       DCD     __initial_sp              ;        0: Top of Stack
                DCD     Reset_Handler             ;        1: Reset Handler
                DCD     NMI_Handler               ;        2: NMI Handler
                DCD     HardFault_Handler         ;        3: Hard Fault Handler
                DCD     MemManage_Handler         ;        4: MPU Fault Handler
                DCD     BusFault_Handler          ;        5: Bus Fault Handler
                DCD     UsageFault_Handler        ;        6: Usage Fault Handler
                DCD     0                         ;        7: Reserved
                DCD     0                         ;        8: Reserved
                DCD     0                         ;        9: Reserved
                DCD     0                         ;       10: Reserved
                DCD     SVC_Handler               ;       11: SVCall Handler
                DCD     DebugMon_Handler          ;       12: Debug Monitor Handler
                DCD     0                         ;       13: Reserved
                DCD     PendSV_Handler            ;       14: PendSV Handler
                DCD     SysTick_Handler           ;       15: SysTick Handler

                ; External Interrupts
	            ; ------ Timer ------
                DCD     TAUJ2I0_IRQHandler        ; 16 +   0: Timer ch:0 Interrupt
                DCD     TAUJ2I1_IRQHandler        ; 16 +   1: Timer ch:1 Interrupt
                DCD     TAUJ2I2_IRQHandler        ; 16 +   2: Timer ch:2 Interrupt
                DCD     TAUJ2I3_IRQHandler        ; 16 +   3: Timer ch:3 Interrupt

	            ; ------ UART ------
                DCD     UAJ0TIT_IRQHandler        ; 16 +   4: UART ch:0 TX Interrupt
                DCD     UAJ0TIR_IRQHandler        ; 16 +   5: UART ch:0 RX Interrupt
                DCD     UAJ1TIT_IRQHandler        ; 16 +   6: UART ch:1 TX Interrupt
                DCD     UAJ1TIR_IRQHandler        ; 16 +   7: UART ch:1 RX Interrupt

	            ; ------ CSI ------
                DCD     CSIH0IC_IRQHandler        ; 16 +   8: CSI ch:0 communication Interrupt
                DCD     CSIH0IR_IRQHandler        ; 16 +   9: CSI ch:0 RX Interrupt
                DCD     CSIH0IJC_IRQHandler       ; 16 +  10: CSI ch:0 error Interrupt
                DCD     CSIH1IC_IRQHandler        ; 16 +  11: CSI ch:1 communication Interrupt
                DCD     CSIH1IR_IRQHandler        ; 16 +  12: CSI ch:1 RX Interrupt
                DCD     CSIH1IJC_IRQHandler       ; 16 +  13: CSI ch:1 error Interrupt

	            ; ------ IIC ------
                DCD     IICB0TIA_IRQHandler       ; 16 +  14: IIC ch:0 TX/RX Interrupt
                DCD     IICB1TIA_IRQHandler       ; 16 +  15: IIC ch:1 TX/RX Interrupt

	            ; ------ CAN ------
                DCD     FCN0REC_IRQHandler        ; 16 +  16: CAN ch:0 RX Interrupt
                DCD     FCN0TRX_IRQHandler        ; 16 +  17: CAN ch:0 TX Interrupt
                DCD     FCN0WUP_IRQHandler        ; 16 +  18: CAN ch:0 wake up Interrupt
                DCD     FCN1REC_IRQHandler        ; 16 +  19: CAN ch:1 RX Interrupt
                DCD     FCN1TRX_IRQHandler        ; 16 +  20: CAN ch:1 TX Interrupt
                DCD     FCN1WUP_IRQHandler        ; 16 +  21: CAN ch:1 wake up Interrupt

	            ; ------ DMAC ------
                DCD     DMA00_IRQHandler          ; 16 +  22: DMAC ch:0 transfer Interrupt
                DCD     DMA01_IRQHandler          ; 16 +  23: DMAC ch:1 transfer Interrupt
                DCD     DMA02_IRQHandler          ; 16 +  24: DMAC ch:2 transfer Interrupt
                DCD     DMA03_IRQHandler          ; 16 +  25: DMAC ch:3 transfer Interrupt
                DCD     DMA10_IRQHandler          ; 16 +  26: RTPORT DMAC transfer Interrupt

	            ; ------ EtherCAT ------
                DCD     CATSYNC0_IRQHandler       ; 16 +  27: EtherCAT sync1 Interrupt
                DCD     CATSYNC1_IRQHandler       ; 16 +  28: EtherCAT sync0 Interrupt
                DCD     CAT_IRQHandler            ; 16 +  29: EtherCAT Interrupt
                DCD     CATSOF_IRQHandler         ; 16 +  30: EtherCAT Interrupt
                DCD     CATEOF_IRQHandler         ; 16 +  31: EtherCAT Interrupt

	            ; ------ Inter buffer DMA ------
                DCD     BUFDMA_IRQHandler         ; 16 +  32: Inter buffer DMA Interrupt

	            ; ------ Ether PHY ------
                DCD     PHY0_IRQHandler           ; 16 +  33: Ether PHY0 Interrupt
                DCD     PHY1_IRQHandler           ; 16 +  34: Ether PHY1 Interrupt

	            ; ------ Ether MAC ------
                DCD     ETHMII_IRQHandler         ; 16 +  35: Ether MAC MII Interrupt
                DCD     ETHPAUSE_IRQHandler       ; 16 +  36: Ether MAC PAUSE Interrupt
                DCD     ETHTX_IRQHandler          ; 16 +  37: Ether MAC TX complete Interrupt

	            ; ------ Ether Switch ------
                DCD     ETHSW_IRQHandler          ; 16 +  38: EtherSwitch interrupt
                DCD     ETHSWDLR_IRQHandler       ; 16 +  39: EtherSwitch DLR interrupt
                DCD     ETHSWSEC_IRQHandler       ; 16 +  40: EtherSwitch second unit interrupt

	            ; ------ Ether MAC ------
                DCD     ETHRXFIFO_IRQHandler      ; 16 +  41: Ether MAC RX FIFO overflow Interrupt
                DCD     ETHTXFIFO_IRQHandler      ; 16 +  42: Ether MAC TX FIFO underflow Interrupt
                DCD     ETHRXDMA_IRQHandler       ; 16 +  43: Ether MAC RX DMA complete Interrupt
                DCD     ETHTXDMA_IRQHandler       ; 16 +  44: Ether MAC TX DMA complete Interrupt
                DCD     MACDMARXFRM_IRQHandler    ; 16 +  45: Ether MAC RX DMA success Interrupt

	            ; ------ Host I/F ------
                DCD     HOSTIF_IRQHandler         ; 16 +  46: Host I/F Interrupt

	            ; ------ Port ------
                DCD     INTPZ0_IRQHandler         ; 16 +  47: INTPZ0 Interrupt
                DCD     INTPZ1_IRQHandler         ; 16 +  48: INTPZ1 Interrupt
                DCD     INTPZ2_IRQHandler         ; 16 +  49: INTPZ2 Interrupt
                DCD     INTPZ3_IRQHandler         ; 16 +  50: INTPZ3 Interrupt
                DCD     INTPZ4_IRQHandler         ; 16 +  51: INTPZ4 Interrupt
                DCD     INTPZ5_IRQHandler         ; 16 +  52: INTPZ5 Interrupt
                DCD     INTPZ6_IRQHandler         ; 16 +  53: INTPZ6 Interrupt
                DCD     INTPZ7_IRQHandler         ; 16 +  54: INTPZ7 Interrupt
                DCD     INTPZ8_IRQHandler         ; 16 +  55: INTPZ8 Interrupt
                DCD     INTPZ9_IRQHandler         ; 16 +  56: INTPZ9 Interrupt
                DCD     INTPZ10_IRQHandler        ; 16 +  57: INTPZ10 Interrupt
                DCD     INTPZ11_IRQHandler        ; 16 +  58: INTPZ11 Interrupt
                DCD     INTPZ12_IRQHandler        ; 16 +  59: INTPZ12 Interrupt
                DCD     INTPZ13_IRQHandler        ; 16 +  60: INTPZ13 Interrupt
                DCD     INTPZ14_IRQHandler        ; 16 +  61: INTPZ14 Interrupt
                DCD     INTPZ15_IRQHandler        ; 16 +  62: INTPZ15 Interrupt
                DCD     INTPZ16_IRQHandler        ; 16 +  63: INTPZ16 Interrupt
                DCD     INTPZ17_IRQHandler        ; 16 +  64: INTPZ17 Interrupt
                DCD     INTPZ18_IRQHandler        ; 16 +  65: INTPZ18 Interrupt
                DCD     INTPZ19_IRQHandler        ; 16 +  66: INTPZ19 Interrupt
                DCD     INTPZ20_IRQHandler        ; 16 +  67: INTPZ20 Interrupt
                DCD     INTPZ21_IRQHandler        ; 16 +  68: INTPZ21 Interrupt
                DCD     INTPZ22_IRQHandler        ; 16 +  69: INTPZ22 Interrupt
                DCD     INTPZ23_IRQHandler        ; 16 +  70: INTPZ23 Interrupt
                DCD     INTPZ24_IRQHandler        ; 16 +  71: INTPZ24 Interrupt
                DCD     INTPZ25_IRQHandler        ; 16 +  72: INTPZ25 Interrupt
                DCD     INTPZ26_IRQHandler        ; 16 +  73: INTPZ26 Interrupt
                DCD     INTPZ27_IRQHandler        ; 16 +  74: INTPZ27 Interrupt
                DCD     INTPZ28_IRQHandler        ; 16 +  75: INTPZ28 Interrupt

	            ; ------ HW-RTOS ------
                DCD     HWRTOS_IRQHandler         ; 16 +  76: HW-RTOS Interrupt

	            ; ------ Status/Error Interrupt ------
                DCD     BRAMERR_IRQHandler        ; 16 +  77: Buffer RAM access error Interrupt
                DCD     IICB0TIS_IRQHandler       ; 16 +  78: IIS ch:0 status Interrupt
                DCD     IICB1TIS_IRQHandler       ; 16 +  79: IIS ch:1 status Interrupt
                DCD     WDTA0_IRQHandler          ; 16 +  80:
                DCD     SFLASH_IRQHandler         ; 16 +  81: Serial Flash Interrupt
                DCD     UAJ0TIS_IRQHandler        ; 16 +  82: UART ch:0 status Interrupt
                DCD     UAJ1TIS_IRQHandler        ; 16 +  83: UART ch:1 status Interrupt
                DCD     CSIH0IRE_IRQHandler       ; 16 +  84: CSI ch:0 error Interrupt
                DCD     CSIH1IRE_IRQHandler       ; 16 +  85: CSI ch:1 error Interrupt
                DCD     FCN0ERR_IRQHandler        ; 16 +  86: CAN ch:0 error Interrupt
                DCD     FCN1ERR_IRQHandler        ; 16 +  87: CAN ch:1 error Interrupt
                DCD     DERR0_IRQHandler          ; 16 +  88: General DMAC error Interrupt
                DCD     DERR1_IRQHandler          ; 16 +  89: RTPORT DMAC error Interrupt
                DCD     ETHTXFIFOERR_IRQHandler   ; 16 +  90: Ether MAC TX FIFO error Interrupt
                DCD     ETHRXERR_IRQHandler       ; 16 +  91: Ether MAC RX error Interrupt
                DCD     ETHRXDERR_IRQHandler      ; 16 +  92: Ether MAC RX DMA error Interrupt
                DCD     ETHTXDERR_IRQHandler      ; 16 +  93: Ether MAC TX DMA error Interrupt
                DCD     BUFDMAERR_IRQHandler      ; 16 +  94: Inter buffer DMA error Interrupt
                DCD     ECATWDT_IRQHandler        ; 16 +  95: EtherCAT PDI WDT interrupt
                DCD     ECATRST_IRQHandler        ; 16 +  96: EtherCAT RESET_OUT interrupt
                DCD     0                         ; 16 +  97: Reserved
                DCD     0                         ; 16 +  98: Reserved
                DCD     0                         ; 16 +  99: Reserved
                DCD     0                         ; 16 + 100: Reserved
                DCD     0                         ; 16 + 101: Reserved
                DCD     0                         ; 16 + 102: Reserved
                DCD     0                         ; 16 + 103: Reserved
                DCD     0                         ; 16 + 104: Reserved

	            ; ------ CC-Link IE Feild Network ------
                DCD     CCISYCO_IRQHandler        ; 16 + 105: CC-Link IE Sync Output interrupt
                DCD     CCISYCI_IRQHandler        ; 16 + 106: CC-Link IE Sync Input interrupt
                DCD     CCINMIZ_IRQHandler        ; 16 + 107: CC-Link IE NMIZ interrupt
                DCD     CCIWDTZ_IRQHandler        ; 16 + 108: CC-Link IE WDTZ interrupt
                DCD     CCIINTZ_IRQHandler        ; 16 + 109: CC-Link IE INTZ interrupt
                DCD     CCICLKLOSSZ_IRQHandler    ; 16 + 110: CC-Link IE CLKLOSSZ interrupt
                DCD     CCIMON0_IRQHandler        ; 16 + 111: CC-Link IE MON0 interrupt
                DCD     CCIMON1_IRQHandler        ; 16 + 112: CC-Link IE MON1 interrupt
                DCD     CCIMON2_IRQHandler        ; 16 + 113: CC-Link IE MON2 interrupt
                DCD     CCIMON3_IRQHandler        ; 16 + 114: CC-Link IE MON3 interrupt

	            ; ------ CC-Link  ------
                DCD     CCMRQ_IRQHandler          ; 16 + 115: CC-Link INTRQ interrupt
                DCD     CCSRFSTB_IRQHandler       ; 16 + 116: CC-Link RFSTB interrupt
                DCD     CCSMON3_IRQHandler	      ; 16 + 117: CC-Link MON3 interrupt
__Vectors_End
__Vectors_Size  EQU  __Vectors_End - __Vectors



                AREA    CODE_ROM, CODE, READONLY

; Reset Handler
Reset_Handler   PROC
                EXPORT  Reset_Handler             [WEAK]
                IMPORT  SystemInit
                IMPORT  __main

                ; Branch to SystemInit
                LDR     R0, =SystemInit
                BLX     R0

                ; Branch to pre Main
                LDR     R0, =__main
                BX      R0
                ENDP

NMI_Handler_ROM\
                PROC
                EXPORT  NMI_Handler_ROM
                B       .
                ENDP
                    
HardFault_Handler_ROM\
                PROC
                EXPORT  HardFault_Handler_ROM
                B       .
                ENDP
				
				
; Dummy Exception Handlers (infinite loops which can be modified)

NMI_Handler     PROC
                EXPORT  NMI_Handler               [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                EXPORT  HardFault_Handler         [WEAK]
                B       .
                ENDP
MemManage_Handler\
                PROC
                EXPORT  MemManage_Handler         [WEAK]
                B       .
                ENDP
BusFault_Handler\
                PROC
                EXPORT  BusFault_Handler          [WEAK]
                B       .
                ENDP
UsageFault_Handler\
                PROC
                EXPORT  UsageFault_Handler        [WEAK]
                B       .
                ENDP
SVC_Handler     PROC
                EXPORT  SVC_Handler               [WEAK]
                B       .
                ENDP
DebugMon_Handler\
                PROC
                EXPORT  DebugMon_Handler          [WEAK]
                B       .
                ENDP
PendSV_Handler  PROC
                EXPORT  PendSV_Handler            [WEAK]
                B       .
                ENDP
SysTick_Handler PROC
                EXPORT  SysTick_Handler           [WEAK]
                B       .
                ENDP

Default_Handler PROC

                EXPORT  TAUJ2I0_IRQHandler        [WEAK]
                EXPORT  TAUJ2I1_IRQHandler        [WEAK]
                EXPORT  TAUJ2I2_IRQHandler        [WEAK]
                EXPORT  TAUJ2I3_IRQHandler        [WEAK]
                EXPORT  UAJ0TIT_IRQHandler        [WEAK]
                EXPORT  UAJ0TIR_IRQHandler        [WEAK]
                EXPORT  UAJ1TIT_IRQHandler        [WEAK]
                EXPORT  UAJ1TIR_IRQHandler        [WEAK]
                EXPORT  CSIH0IC_IRQHandler        [WEAK]
                EXPORT  CSIH0IR_IRQHandler        [WEAK]
                EXPORT  CSIH0IJC_IRQHandler       [WEAK]
                EXPORT  CSIH1IC_IRQHandler        [WEAK]
                EXPORT  CSIH1IR_IRQHandler        [WEAK]
                EXPORT  CSIH1IJC_IRQHandler       [WEAK]
                EXPORT  IICB0TIA_IRQHandler       [WEAK]
                EXPORT  IICB1TIA_IRQHandler       [WEAK]
                EXPORT  FCN0REC_IRQHandler        [WEAK]
                EXPORT  FCN0TRX_IRQHandler        [WEAK]
                EXPORT  FCN0WUP_IRQHandler        [WEAK]
                EXPORT  FCN1REC_IRQHandler        [WEAK]
                EXPORT  FCN1TRX_IRQHandler        [WEAK]
                EXPORT  FCN1WUP_IRQHandler        [WEAK]
                EXPORT  DMA00_IRQHandler          [WEAK]
                EXPORT  DMA01_IRQHandler          [WEAK]
                EXPORT  DMA02_IRQHandler          [WEAK]
                EXPORT  DMA03_IRQHandler          [WEAK]
                EXPORT  DMA10_IRQHandler          [WEAK]
                EXPORT  CATSYNC0_IRQHandler       [WEAK]
                EXPORT  CATSYNC1_IRQHandler       [WEAK]
                EXPORT  CAT_IRQHandler            [WEAK]
                EXPORT  CATSOF_IRQHandler         [WEAK]
                EXPORT  CATEOF_IRQHandler         [WEAK]
                EXPORT  BUFDMA_IRQHandler         [WEAK]
                EXPORT  PHY0_IRQHandler           [WEAK]
                EXPORT  PHY1_IRQHandler           [WEAK]
                EXPORT  ETHMII_IRQHandler         [WEAK]
                EXPORT  ETHPAUSE_IRQHandler       [WEAK]
                EXPORT  ETHTX_IRQHandler          [WEAK]
                EXPORT  ETHSW_IRQHandler          [WEAK]
                EXPORT  ETHSWDLR_IRQHandler       [WEAK]
                EXPORT  ETHSWSEC_IRQHandler       [WEAK]
                EXPORT  ETHRXFIFO_IRQHandler      [WEAK]
                EXPORT  ETHTXFIFO_IRQHandler      [WEAK]
                EXPORT  ETHRXDMA_IRQHandler       [WEAK]
                EXPORT  ETHTXDMA_IRQHandler       [WEAK]
                EXPORT  MACDMARXFRM_IRQHandler    [WEAK]
                EXPORT  HOSTIF_IRQHandler         [WEAK]
                EXPORT  INTPZ0_IRQHandler         [WEAK]
                EXPORT  INTPZ1_IRQHandler         [WEAK]
                EXPORT  INTPZ2_IRQHandler         [WEAK]
                EXPORT  INTPZ3_IRQHandler         [WEAK]
                EXPORT  INTPZ4_IRQHandler         [WEAK]
                EXPORT  INTPZ5_IRQHandler         [WEAK]
                EXPORT  INTPZ6_IRQHandler         [WEAK]
                EXPORT  INTPZ7_IRQHandler         [WEAK]
                EXPORT  INTPZ8_IRQHandler         [WEAK]
                EXPORT  INTPZ9_IRQHandler         [WEAK]
                EXPORT  INTPZ10_IRQHandler        [WEAK]
                EXPORT  INTPZ11_IRQHandler        [WEAK]
                EXPORT  INTPZ12_IRQHandler        [WEAK]
                EXPORT  INTPZ13_IRQHandler        [WEAK]
                EXPORT  INTPZ14_IRQHandler        [WEAK]
                EXPORT  INTPZ15_IRQHandler        [WEAK]
                EXPORT  INTPZ16_IRQHandler        [WEAK]
                EXPORT  INTPZ17_IRQHandler        [WEAK]
                EXPORT  INTPZ18_IRQHandler        [WEAK]
                EXPORT  INTPZ19_IRQHandler        [WEAK]
                EXPORT  INTPZ20_IRQHandler        [WEAK]
                EXPORT  INTPZ21_IRQHandler        [WEAK]
                EXPORT  INTPZ22_IRQHandler        [WEAK]
                EXPORT  INTPZ23_IRQHandler        [WEAK]
                EXPORT  INTPZ24_IRQHandler        [WEAK]
                EXPORT  INTPZ25_IRQHandler        [WEAK]
                EXPORT  INTPZ26_IRQHandler        [WEAK]
                EXPORT  INTPZ27_IRQHandler        [WEAK]
                EXPORT  INTPZ28_IRQHandler        [WEAK]
                EXPORT  HWRTOS_IRQHandler         [WEAK]
                EXPORT  BRAMERR_IRQHandler        [WEAK]
                EXPORT  IICB0TIS_IRQHandler       [WEAK]
                EXPORT  IICB1TIS_IRQHandler       [WEAK]
                EXPORT  WDTA0_IRQHandler          [WEAK]
                EXPORT  SFLASH_IRQHandler         [WEAK]
                EXPORT  UAJ0TIS_IRQHandler        [WEAK]
                EXPORT  UAJ1TIS_IRQHandler        [WEAK]
                EXPORT  CSIH0IRE_IRQHandler       [WEAK]
                EXPORT  CSIH1IRE_IRQHandler       [WEAK]
                EXPORT  FCN0ERR_IRQHandler        [WEAK]
                EXPORT  FCN1ERR_IRQHandler        [WEAK]
                EXPORT  DERR0_IRQHandler          [WEAK]
                EXPORT  DERR1_IRQHandler          [WEAK]
                EXPORT  ETHTXFIFOERR_IRQHandler   [WEAK]
                EXPORT  ETHRXERR_IRQHandler       [WEAK]
                EXPORT  ETHRXDERR_IRQHandler      [WEAK]
                EXPORT  ETHTXDERR_IRQHandler      [WEAK]
                EXPORT  BUFDMAERR_IRQHandler      [WEAK]
                EXPORT  ECATWDT_IRQHandler        [WEAK]
                EXPORT  ECATRST_IRQHandler        [WEAK]
                EXPORT  CCISYCO_IRQHandler        [WEAK]
                EXPORT  CCISYCI_IRQHandler        [WEAK]
                EXPORT  CCINMIZ_IRQHandler        [WEAK]
                EXPORT  CCIWDTZ_IRQHandler        [WEAK]
                EXPORT  CCIINTZ_IRQHandler        [WEAK]
                EXPORT  CCICLKLOSSZ_IRQHandler    [WEAK]
                EXPORT  CCIMON0_IRQHandler        [WEAK]
                EXPORT  CCIMON1_IRQHandler        [WEAK]
                EXPORT  CCIMON2_IRQHandler        [WEAK]
                EXPORT  CCIMON3_IRQHandler        [WEAK]
                EXPORT  CCMRQ_IRQHandler          [WEAK]
                EXPORT  CCSRFSTB_IRQHandler       [WEAK]
                EXPORT  CCSMON3_IRQHandler	      [WEAK]

TAUJ2I0_IRQHandler
TAUJ2I1_IRQHandler
TAUJ2I2_IRQHandler
TAUJ2I3_IRQHandler
UAJ0TIT_IRQHandler
UAJ0TIR_IRQHandler
UAJ1TIT_IRQHandler
UAJ1TIR_IRQHandler
CSIH0IC_IRQHandler
CSIH0IR_IRQHandler
CSIH0IJC_IRQHandler
CSIH1IC_IRQHandler
CSIH1IR_IRQHandler
CSIH1IJC_IRQHandler
IICB0TIA_IRQHandler
IICB1TIA_IRQHandler
FCN0REC_IRQHandler
FCN0TRX_IRQHandler
FCN0WUP_IRQHandler
FCN1REC_IRQHandler
FCN1TRX_IRQHandler
FCN1WUP_IRQHandler
DMA00_IRQHandler
DMA01_IRQHandler
DMA02_IRQHandler
DMA03_IRQHandler
DMA10_IRQHandler
CATSYNC0_IRQHandler
CATSYNC1_IRQHandler
CAT_IRQHandler
CATSOF_IRQHandler
CATEOF_IRQHandler
BUFDMA_IRQHandler
PHY0_IRQHandler
PHY1_IRQHandler
ETHMII_IRQHandler
ETHPAUSE_IRQHandler
ETHTX_IRQHandler
ETHSW_IRQHandler
ETHSWDLR_IRQHandler
ETHSWSEC_IRQHandler
ETHRXFIFO_IRQHandler
ETHTXFIFO_IRQHandler
ETHRXDMA_IRQHandler
ETHTXDMA_IRQHandler
MACDMARXFRM_IRQHandler
HOSTIF_IRQHandler
INTPZ0_IRQHandler
INTPZ1_IRQHandler
INTPZ2_IRQHandler
INTPZ3_IRQHandler
INTPZ4_IRQHandler
INTPZ5_IRQHandler
INTPZ6_IRQHandler
INTPZ7_IRQHandler
INTPZ8_IRQHandler
INTPZ9_IRQHandler
INTPZ10_IRQHandler
INTPZ11_IRQHandler
INTPZ12_IRQHandler
INTPZ13_IRQHandler
INTPZ14_IRQHandler
INTPZ15_IRQHandler
INTPZ16_IRQHandler
INTPZ17_IRQHandler
INTPZ18_IRQHandler
INTPZ19_IRQHandler
INTPZ20_IRQHandler
INTPZ21_IRQHandler
INTPZ22_IRQHandler
INTPZ23_IRQHandler
INTPZ24_IRQHandler
INTPZ25_IRQHandler
INTPZ26_IRQHandler
INTPZ27_IRQHandler
INTPZ28_IRQHandler
HWRTOS_IRQHandler
BRAMERR_IRQHandler
IICB0TIS_IRQHandler
IICB1TIS_IRQHandler
WDTA0_IRQHandler
SFLASH_IRQHandler
UAJ0TIS_IRQHandler
UAJ1TIS_IRQHandler
CSIH0IRE_IRQHandler
CSIH1IRE_IRQHandler
FCN0ERR_IRQHandler
FCN1ERR_IRQHandler
DERR0_IRQHandler
DERR1_IRQHandler
ETHTXFIFOERR_IRQHandler
ETHRXERR_IRQHandler
ETHRXDERR_IRQHandler
ETHTXDERR_IRQHandler
BUFDMAERR_IRQHandler
ECATWDT_IRQHandler
ECATRST_IRQHandler
CCISYCO_IRQHandler
CCISYCI_IRQHandler
CCINMIZ_IRQHandler
CCIWDTZ_IRQHandler
CCIINTZ_IRQHandler
CCICLKLOSSZ_IRQHandler
CCIMON0_IRQHandler
CCIMON1_IRQHandler
CCIMON2_IRQHandler
CCIMON3_IRQHandler
CCMRQ_IRQHandler
CCSRFSTB_IRQHandler
CCSMON3_IRQHandler
                B       .

                ENDP



                ALIGN


; User Initial Stack & Heap

                IF      :DEF:__MICROLIB

                EXPORT  __initial_sp
                EXPORT  __heap_base
                EXPORT  __heap_limit

                ELSE

                IMPORT  __use_two_region_memory
                EXPORT  __user_initial_stackheap
__user_initial_stackheap

                LDR     R0, =  Heap_Mem
                LDR     R1, =(Stack_Mem + Stack_Size)
                LDR     R2, = (Heap_Mem +  Heap_Size)
                LDR     R3, = Stack_Mem
                BX      LR

                ALIGN

                ENDIF


                END
