/**
 *******************************************************************************
 * @file  sflash.h
 * @brief Serial Flash ROM control header for R-IN32M3
 * 
 * @note 
 * Copyright (C) 2012,2013 Renesas Electronics Corporation 
 * Copyright (C) 2012,2013 Renesas Micro Systems Co., Ltd. 
 * 
 * @par
 *  This is a sample program. 
 *  Renesas Electronics assumes no responsibility for any losses incurred. 
 * 
 *******************************************************************************
 */

#ifndef	SFLASH_H__
#define	SFLASH_H__

/*============================================================================*/
/* I N C L U D E                                                              */
/*============================================================================*/
#include "RIN32M3.h"

/*============================================================================*/
/* T Y P E D E F                                                              */
/*============================================================================*/

/*============================================================================*/
/* D E F I N E                                                                */
/*============================================================================*/
/* base address */
#define SFLASH_BASE_ADDRESS (0x02000000)	/**< Mapped base address of Serial Flash memory */

/* flash configuration */
/* S25FL032P */
/* channel information */
#define SFLASH_CHANNEL_MAX  (1)				/**< Serial Flash ROM Channel count */
/* device information (ch 0) */
#define SFLASH_DEVICE_SIZE  (1 << 22)		/**< Serial Flash ROM Device size */
#define SFLASH_ERASE_SIZE   (1 << 16)		/**< Serial Flash ROM Erase size */
#define SFLASH_PROGRAM_SIZE (1 <<  8)		/**< Serial Flash ROM Program size */

/*============================================================================*/
/* P R O T O T Y P E                                                          */
/*============================================================================*/
int sflash_init(uint32_t ch);
int sflash_read(uint32_t ch, uint8_t* buf, uint32_t addr, uint32_t size);
int sflash_program(uint32_t ch, uint8_t* buf, uint32_t addr, uint32_t size);
int sflash_erase(uint32_t ch, uint32_t addr, uint32_t size);

#endif // SFLASH_H__
